aboutsummaryrefslogtreecommitdiff
path: root/vcal.h
diff options
context:
space:
mode:
authorHugo Hörnquist <hugo@lysator.liu.se>2019-02-18 22:39:56 +0100
committerHugo Hörnquist <hugo@lysator.liu.se>2019-02-18 22:39:56 +0100
commit33fa5b5d0c512c72c1d50b9420a36431cd10eb5d (patch)
tree6642ec876ecd15ce62f83075d7f9d261050fe3a6 /vcal.h
parentStart rework of guile interface. (diff)
downloadcalp-33fa5b5d0c512c72c1d50b9420a36431cd10eb5d.tar.gz
calp-33fa5b5d0c512c72c1d50b9420a36431cd10eb5d.tar.xz
Made to compile as C++.
Diffstat (limited to 'vcal.h')
-rw-r--r--vcal.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/vcal.h b/vcal.h
index 21358cb6..1c96c4c6 100644
--- a/vcal.h
+++ b/vcal.h
@@ -46,7 +46,7 @@
* Helper macros for accessing fields in
* content_line, content_set, and param_set
*
- * TODO find a better way to do this.
+ * TODO find a better way to do self.
*/
/* ptr -> ptr */
@@ -68,12 +68,12 @@
/*
* Resolves a collision in some form of structure (probably a hash-map
* or a trie). If dest is NULL just return new. Otherwise mutates dest
* to have the correct form, and returns it. Destroying new in the
* process.
*/
content_line* RESOLVE(content_line)
- (content_line* dest, content_line* new);
+ (content_line* dest, content_line* new_);
#define TYPE content_line
#include "trie.h"
@@ -68,12 +68,12 @@
/*
* Resolves a collision in some form of structure (probably a hash-map
- * or a trie). If dest is NULL just return new. Otherwise mutates dest
- * to have the correct form, and returns it. Destroying new in the
+ * or a trie). If dest is NULL just return new_. Otherwise mutates dest
+ * to have the correct form, and returns it. Destroying new_ in the
* process.
*/